/*
 *	$Id$
 */

#ifndef  __MKF_8BIT_PARSER_H__
#define  __MKF_8BIT_PARSER_H__


#include  "mkf_parser.h"


mkf_parser_t *  mkf_koi8_r_parser_new(void) ;

mkf_parser_t *  mkf_koi8_u_parser_new(void) ;

mkf_parser_t *  mkf_koi8_t_parser_new(void) ;

mkf_parser_t *  mkf_georgian_ps_parser_new(void) ;

mkf_parser_t *  mkf_cp1250_parser_new(void) ;

mkf_parser_t *  mkf_cp1251_parser_new(void) ;

mkf_parser_t *  mkf_cp1252_parser_new(void) ;

mkf_parser_t *  mkf_cp1253_parser_new(void) ;

mkf_parser_t *  mkf_cp1254_parser_new(void) ;

mkf_parser_t *  mkf_cp1255_parser_new(void) ;

mkf_parser_t *  mkf_cp1256_parser_new(void) ;

mkf_parser_t *  mkf_cp1257_parser_new(void) ;

mkf_parser_t *  mkf_cp1258_parser_new(void) ;

mkf_parser_t *  mkf_cp874_parser_new(void) ;

mkf_parser_t *  mkf_viscii_parser_new(void) ;

mkf_parser_t *  mkf_iscii_assamese_parser_new(void) ;

mkf_parser_t *  mkf_iscii_bengali_parser_new(void) ;

mkf_parser_t *  mkf_iscii_gujarati_parser_new(void) ;

mkf_parser_t *  mkf_iscii_hindi_parser_new(void) ;

mkf_parser_t *  mkf_iscii_kannada_parser_new(void) ;

mkf_parser_t *  mkf_iscii_malayalam_parser_new(void) ;

mkf_parser_t *  mkf_iscii_oriya_parser_new(void) ;

mkf_parser_t *  mkf_iscii_punjabi_parser_new(void) ;

mkf_parser_t *  mkf_iscii_roman_parser_new(void) ;

mkf_parser_t *  mkf_iscii_tamil_parser_new(void) ;

mkf_parser_t *  mkf_iscii_telugu_parser_new(void) ;


#endif
